@@ -108,7 +108,7 @@ class GSPeerConnectionBroadcasterPi:
                         await pc.close()
                         self.peerConnections.pop(id, None)
 
-                transceiver = pc.addTransceiver("video")
+                transceiver = pc.addTransceiver("video", direction="sendonly")
                 capabilities = RTCRtpSender.getCapabilities("video")
                 preferences = list(filter(lambda x: x.name == "H264", capabilities.codecs))
                 preferences += list(filter(lambda x: x.name == "rtx", capabilities.codecs))
@@ -129,8 +129,8 @@ class GSPeerConnectionBroadcasterPi:
                                                     "sdp": pc.localDescription.sdp})})
 
             @self.sio.event
-            async def joined():
-                await self.sio.emit("broadcaster")
+            async def joined(id):
+                await self.sio.emit("broadcaster", id)
 
             @self.sio.event
             async def disconnectPeer(id):
@@ -152,6 +152,3 @@ class GSPeerConnectionBroadcasterPi:
             await self.sio.connect(
                 f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}')
             await self.sio.wait()
-
-
-
