@@ -116,8 +116,8 @@ class GSPeerConnectionBroadcasterUniversal:
                                                 "sdp": pc.localDescription.sdp})})
 
         @self.sio.event
-        async def joined():
-            await self.sio.emit("broadcaster")
+        async def joined(id):
+            await self.sio.emit("broadcaster",id)
 
         @self.sio.event
         async def disconnectPeer(id):
