@@ -53,7 +53,7 @@ class GSPeerConnectionWatcher:
             self.logger.info('connection established')
 
         @self.sio.event
-        async def joined():
+        async def joined(id):
             self.logger.info("joined")
 
         @self.sio.event
@@ -63,7 +63,7 @@ class GSPeerConnectionWatcher:
             else:
                 self.peerConnections = RTCPeerConnection()
 
-            self.peerConnections.addTransceiver('video', direction='sendrecv')
+            self.peerConnections.addTransceiver('video', direction='recvonly')
 
             @self.peerConnections.on("iceconnectionstatechange")
             async def on_iceconnectionstatechange():
@@ -80,14 +80,12 @@ class GSPeerConnectionWatcher:
                         self.logger.info("on track received.Recording started")
                         await self.ontrack(self.gsdbs, track, self.target)
                     if self.onframe is not None:
-                        self.logger.info("on track received. Onframe started")
+                        self.logger.info("on track received. onframe started")
                         blackHole = MediaBlackhole()
-                        mediaTrack = VideoTransformTrack(
-                            relay.subscribe(track), self.gsdbs, self.target, self.onframe)
+                        mediaTrack = VideoTransformTrack(relay.subscribe(track), self.gsdbs, self.target, self.onframe)
                         blackHole.addTrack(mediaTrack)
                         await blackHole.start()
 
-
                 @track.on("ended")
                 async def on_ended():
                     self.ontrackended(self.gsdbs, self.target)
